@@ -207,10 +207,15 @@ class Column(object):
 class Bytes(Column):
     db_type = 'blob'
 
+    class Quoter(ValueQuoter):
+        def __str__(self):
+            return '0x' + self.value.encode('hex')
+
     def to_database(self, value):
         val = super(Bytes, self).to_database(value)
         if val is None: return
-        return '0x' + val.encode('hex')
+
+        return self.Quoter(val)
 
     def to_python(self, value):
         #return value[2:].decode('hex')
