@@ -1,3 +1,4 @@
+import time
 from datetime import datetime, timedelta
 from cqlengine.functions import QueryValue
 from cqlengine.operators import BaseWhereOperator, InOperator
@@ -6,25 +7,6 @@ from cqlengine.operators import BaseWhereOperator, InOperator
 class StatementException(Exception): pass
 
 
-# Monkey patch cql_quote to allow raw hex values
-import cql.query
-
-
-def cql_quote_replacement(term):
-    if isinstance(term, basestring) and term.startswith('0x'):
-        if isinstance(term, unicode):
-            return term.encode('utf8')
-        else:
-            return term
-    elif isinstance(term, unicode):
-        return "'%s'" % cql.query.__escape_quotes(term.encode('utf8'))
-    elif isinstance(term, (str, bool)):
-        return "'%s'" % cql.query.__escape_quotes(str(term))
-    else:
-        return str(term)
-cql.query.cql_quote = cql_quote_replacement
-
-
 class ValueQuoter(object):
 
     def __init__(self, value):
@@ -496,7 +478,7 @@ class BaseCQLStatement(object):
         else:
             tmp = self.timestamp
 
-        return long(((tmp - datetime.fromtimestamp(0)).total_seconds()) * 1000000)
+        return long(time.mktime(tmp.timetuple()) * 1e+6 + tmp.microsecond)
 
     def __unicode__(self):
         raise NotImplementedError
